#
# spec file for package python-django-localflavor
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-django-localflavor
Version:        4.0
Release:        2.3
Summary:        Country-specific Django helpers
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/django/django-localflavor
Source:         https://github.com/django/django-localflavor/archive/%{version}.tar.gz#/django-localflavor-%{version}.tar.gz
# PATCH-FIX-UPSTREAM https://github.com/django/django-localflavor/commit/a0bb1b5b56be1d3f1a4ebb886621961b458ab74e Fix # 502 -- Update Python and Django versions
Patch0:         dj5.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 2.2
Requires:       python-python-stdnum >= 1.6
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django >= 2.2}
BuildRequires:  %{python_module coverage}
BuildRequires:  %{python_module invoke >= 1.2}
BuildRequires:  %{python_module python-stdnum >= 1.6}
# /SECTION
%python_subpackages

%description
Country-specific Django helpers.

%prep
%autosetup -p1 -n django-localflavor-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec -m invoke test

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/localflavor
%{python_sitelib}/django_localflavor-%{version}*info

%changelog
* Fri Nov  8 2024 Markéta Machová <mmachova@suse.com>
- Add upstream dj5.patch to fix tests with new Django
* Sun Apr 23 2023 Dirk Müller <dmueller@suse.com>
- update to 4.0:
  * Nepal LocalFlavor: Support for Nepal added
  * Belarus localflavor
  * Ghana localflavor
  * New fields for existing flavors:
  * Added `fr.forms.FRRNAField` models field
  * Added permanent account number(PAN) field in Indian flavor.
  * Added the Canadian Models fields.
  * Modifications to existing flavors:
  * Properly validate IBANs using BBAN to ensure invalid IBANs
    cannot be entered,
  * updated IBAN_SEPA_COUNTRIES and IBAN_COUNTRY_CODE_LENGTH to
    latest data
  * Fix typo in Marijampolė county name in LTCountySelect
  * Add support for new Finnish identity codes
  * CIF spanish starting with 'U' bug resolved
  * Fix error code for BRPostalCodeValidator
  * Fix spelling of the India state of Chhattisgarh
  * Fix CURP regex for MX flavor
  * Removed inconvenient word VACA from CURP_INCONVENIENT_WORDS
    for MX flavor
  * Other changes:
  * Use 'return value' when value is in the empty_values list
  * Dropped support for Django 2.2, 3.0 and 3.1.
  * Dropped support for Python 3.5.
  * Added support for Python 3.10 and 3.11.
* Fri Jan  7 2022 John Vandenberg <jayvdb@gmail.com>
- Skip Tumbleweed Python 3.6 incompatible with Django 4
* Sun Dec 26 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v3.1
  * Breaking data change: A schema and data migration are required
    for users of mx.models.MXStateField and mx.forms.MXStateSelect.
    The following steps are required:
    + run manage.py makemigrations to generate a schema migration
    + migrate DIF to CDMX with a data migration
  * Breaking data change: A data migration is required for users of
    in_.models.INStateField and in_.forms.INStateSelect.
    The following data migrations are required:
    + Migrate CG to CT for Chattisgarh
    + Migrate UA to UT for Uttarakhand
    + Migrate DD and DN to DH for Dadra and Nagar Haveli and Daman and Diu
  * A warning message will be displayed when mx.models.MXStateField,
    mx.forms.MXStateSelect, in_.models.INStateField or
    in_.forms.INStateSelect are used. See the localflavor online docs
    for instructions on how to suppress this warning once the migration
    has been completed.
  * Fix fr.forms.FRNationalIdentificationNumber validation for people
    born overseas
  * Breaking data change: Updated Indian states and union territories
    names and code as per iso 3166 (iso.org/obp/ui/#iso:code:3166:IN).
    The key for Chattisgarh has been changed from CG to CT, the key
    for Uttarakhand has been changed from UA to UT, and the keys DD
    (Dadra and Nagar Haveli) and DN (Daman and Diu) have been removed
    and combined into DH (Dadra and Nagar Haveli and Daman and Diu).
    Ladakh (LA) is the new addition in the Union Territories.
    There are also a few modifications in the States and
    Union Territories names: Orissa (OR) is now Odisha (OR), Pondicherry (PY)
    is now Puducherry (PY) Andaman and Nicobar (AN) is now Andaman and
    Nicobar Islands (AN).
  * Correct sorting of US_STATES to sort by full name rather than code
  * Added new region for CL (gh-432, gh-433).
  * Updated IBAN validation for changes in IBAN Registry release 89, March 2021.
  * Breaking data change: mx.mx_states.STATE_CHOICES has been updated
    to change DIF/Distrito Federal to CDMX/Ciudad de México, the legal
    name for this state as of 29 January 2016.
  * Extended validation of BICs to match official SEPA regulations.
  * Removed positional arguments (*args) from form fields that inherit
    from Django's forms.CharField and forms.Field. Positional arguments
    are not supported in the the parent form and did not work.
  * Added error codes to all ValidationError`s as recommended by
    `Django's form validation documentation.
  * Renamed zh_CN and zh_TW locales to zh_Hans and zh_Hant
    respectively to match the Django locale names.
* Tue Mar 31 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v3.0.1
* Sun Apr 21 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v2.1
